# Changelog

## 0.5.1 (2025-07-04)

Full Changelog: [v0.5.0...v0.5.1](https://github.com/semilattice-research/semilattice-sdk-python/compare/v0.5.0...v0.5.1)

### Features

* **api:** manual updates ([9b0a7e2](https://github.com/semilattice-research/semilattice-sdk-python/commit/9b0a7e21492a10a2f1bb34999cfa2788bfb7150b))


### Chores

* update SDK settings ([bf159a0](https://github.com/semilattice-research/semilattice-sdk-python/commit/bf159a01f6ecf51939679618f227d5d81606b8ef))

## 0.5.0 (2025-07-03)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/semilattice-research/semilattice-sdk-python/compare/v0.4.0...v0.5.0)

### Features

* **api:** fixing answers endpoint method ([fb080ed](https://github.com/semilattice-research/semilattice-sdk-python/commit/fb080ed0cd4067d5ed123298d0859b21cf4a8945))

## 0.4.0 (2025-07-03)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/semilattice-research/semilattice-sdk-python/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([349da43](https://github.com/semilattice-research/semilattice-sdk-python/commit/349da439a2a84b9179e1891a27c40e300b2d2d6c))
* **api:** api update ([26d50b0](https://github.com/semilattice-research/semilattice-sdk-python/commit/26d50b08bd4e0ea7088515820603e8bd3c0383ff))
* **api:** api update ([ef04297](https://github.com/semilattice-research/semilattice-sdk-python/commit/ef04297db9a609c097eace84e84ee0150c9f8d3c))
* **api:** api update ([f627d7a](https://github.com/semilattice-research/semilattice-sdk-python/commit/f627d7ac732104d37403af82754625708a63cc86))
* **api:** api update ([3951c4b](https://github.com/semilattice-research/semilattice-sdk-python/commit/3951c4b31c8657c4e92fc9fa791890e448b51845))
* **api:** api update ([ded78bd](https://github.com/semilattice-research/semilattice-sdk-python/commit/ded78bda973bad567f96e3b701a149112fe3aff2))
* **api:** api update ([#5](https://github.com/semilattice-research/semilattice-sdk-python/issues/5)) ([1be7d8a](https://github.com/semilattice-research/semilattice-sdk-python/commit/1be7d8afdb910bed2a3e0e4f93cc4e3008ef31f5))
* **api:** config updates ([4a847de](https://github.com/semilattice-research/semilattice-sdk-python/commit/4a847deca9019ff667129f127fd43fe274a52fe9))
* **api:** fixing python package name ([b8837e3](https://github.com/semilattice-research/semilattice-sdk-python/commit/b8837e3b774b37cb801e6913113eab8a015a64a2))
* **api:** manual updates ([96e6336](https://github.com/semilattice-research/semilattice-sdk-python/commit/96e633607e70c7536ff8060fa67785d3b4c5fe74))
* **api:** manual updates ([fbe8299](https://github.com/semilattice-research/semilattice-sdk-python/commit/fbe82999067e99eb158eef340b1c2e3c154f2981))
* **api:** manual updates ([#3](https://github.com/semilattice-research/semilattice-sdk-python/issues/3)) ([90c155a](https://github.com/semilattice-research/semilattice-sdk-python/commit/90c155a3f43a2756877c6bc2cc62ae60e38c619f))
* **api:** renaming methods ([21cf85e](https://github.com/semilattice-research/semilattice-sdk-python/commit/21cf85e0b669c2219f3bbc86a2885beb00c31971))
* **client:** add follow_redirects request option ([cf0e473](https://github.com/semilattice-research/semilattice-sdk-python/commit/cf0e4736399bbe791bd0bef37d8d40d472ce64cc))


### Bug Fixes

* **package:** support direct resource imports ([dd889d4](https://github.com/semilattice-research/semilattice-sdk-python/commit/dd889d4ad218c2a0ae4d93d50ee1a0d405077362))
* **perf:** optimize some hot paths ([a146e96](https://github.com/semilattice-research/semilattice-sdk-python/commit/a146e967b43b87a81209ff376fca8722d5de3b19))
* **perf:** skip traversing types for NotGiven values ([d24af7e](https://github.com/semilattice-research/semilattice-sdk-python/commit/d24af7eb621ec4c78b84c29febb04dd545a1f914))
* **pydantic v1:** more robust ModelField.annotation check ([12ba194](https://github.com/semilattice-research/semilattice-sdk-python/commit/12ba19402745ab6352c8028f900a850a4b82a3fc))


### Chores

* broadly detect json family of content-type headers ([1ee5757](https://github.com/semilattice-research/semilattice-sdk-python/commit/1ee5757a17bcbcfdf4931c8a7b5b62b5487e0901))
* **ci:** add timeout thresholds for CI jobs ([220d4f8](https://github.com/semilattice-research/semilattice-sdk-python/commit/220d4f89a1ff16d81f1ae6833302f87ba08ffd90))
* **ci:** fix installation instructions ([645a083](https://github.com/semilattice-research/semilattice-sdk-python/commit/645a08329fe86ae87e0a27a532e5afc43bf7592f))
* **ci:** only use depot for staging repos ([8debc64](https://github.com/semilattice-research/semilattice-sdk-python/commit/8debc6407d709efbc5569258c13f6a8010ac2f43))
* **ci:** upload sdks to package manager ([b37411d](https://github.com/semilattice-research/semilattice-sdk-python/commit/b37411d3c18aed393966cf3d77a11ced328b580b))
* **client:** minor internal fixes ([564782e](https://github.com/semilattice-research/semilattice-sdk-python/commit/564782edafc8d4fbd1cd8289b7f445986e45886d))
* configure new SDK language ([c1ac8c1](https://github.com/semilattice-research/semilattice-sdk-python/commit/c1ac8c1cd30afbc6d70f5471cf1babd49b0c12c6))
* **docs:** grammar improvements ([8733a3f](https://github.com/semilattice-research/semilattice-sdk-python/commit/8733a3f4c68b2f4e8990d53a381789bea1f392fa))
* **docs:** remove reference to rye shell ([f0acd2b](https://github.com/semilattice-research/semilattice-sdk-python/commit/f0acd2bfb7ce9b504c2979c2f39fcaafe5ac316f))
* go live ([#1](https://github.com/semilattice-research/semilattice-sdk-python/issues/1)) ([3bd0d01](https://github.com/semilattice-research/semilattice-sdk-python/commit/3bd0d0143568a7f121ec2116971bb14005fac541))
* **internal:** avoid errors for isinstance checks on proxies ([7b33f65](https://github.com/semilattice-research/semilattice-sdk-python/commit/7b33f6598978418400b58113891571f2a082b3e4))
* **internal:** base client updates ([e07dba5](https://github.com/semilattice-research/semilattice-sdk-python/commit/e07dba5ba6bf7a3116f3b0d1d684926bfe33f7d1))
* **internal:** bump pyright version ([cdfb893](https://github.com/semilattice-research/semilattice-sdk-python/commit/cdfb893656d2e4d749538c64e88d93b6fc8b5e18))
* **internal:** codegen related update ([7772d31](https://github.com/semilattice-research/semilattice-sdk-python/commit/7772d31ef9565b3d897d2b3e33bfafeadc6a0af4))
* **internal:** codegen related update ([587d5d0](https://github.com/semilattice-research/semilattice-sdk-python/commit/587d5d00025329884b13ec67030adcf39b925959))
* **internal:** expand CI branch coverage ([a39b967](https://github.com/semilattice-research/semilattice-sdk-python/commit/a39b9671db6480c8a6e2035663a486b5da4f98af))
* **internal:** fix list file params ([33a6c27](https://github.com/semilattice-research/semilattice-sdk-python/commit/33a6c27bb6299134e0d1b4adad645bde16b3d83e))
* **internal:** import reformatting ([b4c9a2c](https://github.com/semilattice-research/semilattice-sdk-python/commit/b4c9a2cf6adb923fd2e42b40b5c9d658b77b6ebc))
* **internal:** reduce CI branch coverage ([3bf9c86](https://github.com/semilattice-research/semilattice-sdk-python/commit/3bf9c86e70c7ab3e89313a308772eb1640db8486))
* **internal:** refactor retries to not use recursion ([7207fbe](https://github.com/semilattice-research/semilattice-sdk-python/commit/7207fbea409dcecb07d4589e31d1fee798330e7c))
* **internal:** remove trailing character ([#4](https://github.com/semilattice-research/semilattice-sdk-python/issues/4)) ([d67a567](https://github.com/semilattice-research/semilattice-sdk-python/commit/d67a567fe77fea27b04f5efa9794b69a67f46156))
* **internal:** slight transform perf improvement ([#7](https://github.com/semilattice-research/semilattice-sdk-python/issues/7)) ([93fbfde](https://github.com/semilattice-research/semilattice-sdk-python/commit/93fbfdefeacd57633d19157f5d2c48ee3bbc379f))
* **internal:** update models test ([2bb77e9](https://github.com/semilattice-research/semilattice-sdk-python/commit/2bb77e9cf1c63b0653686a29445c4facd187acb2))
* **internal:** update pyright settings ([0435701](https://github.com/semilattice-research/semilattice-sdk-python/commit/043570179672747b7c741e4f3957d11e1d348c13))
* slight wording improvement in README ([#9](https://github.com/semilattice-research/semilattice-sdk-python/issues/9)) ([fb6dc20](https://github.com/semilattice-research/semilattice-sdk-python/commit/fb6dc208e970eda1bb1ccbbca534a4bac8cdf717))
* sync repo ([b163e5c](https://github.com/semilattice-research/semilattice-sdk-python/commit/b163e5c0f939575aedfd471df378722626dc086e))
* sync repo ([97d4227](https://github.com/semilattice-research/semilattice-sdk-python/commit/97d42274857950a7f55fa61a423345a989d0d466))
* update SDK settings ([623e053](https://github.com/semilattice-research/semilattice-sdk-python/commit/623e053c8b47ee6c661e85ce347359faded3d826))
* update SDK settings ([1a14759](https://github.com/semilattice-research/semilattice-sdk-python/commit/1a1475958197a5c541caef84e040043d79b861f9))
* update SDK settings ([b1b747c](https://github.com/semilattice-research/semilattice-sdk-python/commit/b1b747c3e80189c08c5b555efccc1b06d2303fe7))

## 0.3.0 (2025-07-03)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/semilattice-research/semilattice-sdk-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([349da43](https://github.com/semilattice-research/semilattice-sdk-python/commit/349da439a2a84b9179e1891a27c40e300b2d2d6c))
* **api:** api update ([26d50b0](https://github.com/semilattice-research/semilattice-sdk-python/commit/26d50b08bd4e0ea7088515820603e8bd3c0383ff))
* **api:** api update ([ef04297](https://github.com/semilattice-research/semilattice-sdk-python/commit/ef04297db9a609c097eace84e84ee0150c9f8d3c))
* **api:** api update ([f627d7a](https://github.com/semilattice-research/semilattice-sdk-python/commit/f627d7ac732104d37403af82754625708a63cc86))
* **api:** api update ([3951c4b](https://github.com/semilattice-research/semilattice-sdk-python/commit/3951c4b31c8657c4e92fc9fa791890e448b51845))
* **api:** api update ([ded78bd](https://github.com/semilattice-research/semilattice-sdk-python/commit/ded78bda973bad567f96e3b701a149112fe3aff2))
* **api:** api update ([#5](https://github.com/semilattice-research/semilattice-sdk-python/issues/5)) ([1be7d8a](https://github.com/semilattice-research/semilattice-sdk-python/commit/1be7d8afdb910bed2a3e0e4f93cc4e3008ef31f5))
* **api:** config updates ([4a847de](https://github.com/semilattice-research/semilattice-sdk-python/commit/4a847deca9019ff667129f127fd43fe274a52fe9))
* **api:** fixing python package name ([b8837e3](https://github.com/semilattice-research/semilattice-sdk-python/commit/b8837e3b774b37cb801e6913113eab8a015a64a2))
* **api:** manual updates ([96e6336](https://github.com/semilattice-research/semilattice-sdk-python/commit/96e633607e70c7536ff8060fa67785d3b4c5fe74))
* **api:** manual updates ([fbe8299](https://github.com/semilattice-research/semilattice-sdk-python/commit/fbe82999067e99eb158eef340b1c2e3c154f2981))
* **api:** manual updates ([#3](https://github.com/semilattice-research/semilattice-sdk-python/issues/3)) ([90c155a](https://github.com/semilattice-research/semilattice-sdk-python/commit/90c155a3f43a2756877c6bc2cc62ae60e38c619f))
* **api:** renaming methods ([21cf85e](https://github.com/semilattice-research/semilattice-sdk-python/commit/21cf85e0b669c2219f3bbc86a2885beb00c31971))
* **client:** add follow_redirects request option ([cf0e473](https://github.com/semilattice-research/semilattice-sdk-python/commit/cf0e4736399bbe791bd0bef37d8d40d472ce64cc))


### Bug Fixes

* **package:** support direct resource imports ([dd889d4](https://github.com/semilattice-research/semilattice-sdk-python/commit/dd889d4ad218c2a0ae4d93d50ee1a0d405077362))
* **perf:** optimize some hot paths ([a146e96](https://github.com/semilattice-research/semilattice-sdk-python/commit/a146e967b43b87a81209ff376fca8722d5de3b19))
* **perf:** skip traversing types for NotGiven values ([d24af7e](https://github.com/semilattice-research/semilattice-sdk-python/commit/d24af7eb621ec4c78b84c29febb04dd545a1f914))
* **pydantic v1:** more robust ModelField.annotation check ([12ba194](https://github.com/semilattice-research/semilattice-sdk-python/commit/12ba19402745ab6352c8028f900a850a4b82a3fc))


### Chores

* broadly detect json family of content-type headers ([1ee5757](https://github.com/semilattice-research/semilattice-sdk-python/commit/1ee5757a17bcbcfdf4931c8a7b5b62b5487e0901))
* **ci:** add timeout thresholds for CI jobs ([220d4f8](https://github.com/semilattice-research/semilattice-sdk-python/commit/220d4f89a1ff16d81f1ae6833302f87ba08ffd90))
* **ci:** fix installation instructions ([645a083](https://github.com/semilattice-research/semilattice-sdk-python/commit/645a08329fe86ae87e0a27a532e5afc43bf7592f))
* **ci:** only use depot for staging repos ([8debc64](https://github.com/semilattice-research/semilattice-sdk-python/commit/8debc6407d709efbc5569258c13f6a8010ac2f43))
* **ci:** upload sdks to package manager ([b37411d](https://github.com/semilattice-research/semilattice-sdk-python/commit/b37411d3c18aed393966cf3d77a11ced328b580b))
* **client:** minor internal fixes ([564782e](https://github.com/semilattice-research/semilattice-sdk-python/commit/564782edafc8d4fbd1cd8289b7f445986e45886d))
* configure new SDK language ([c1ac8c1](https://github.com/semilattice-research/semilattice-sdk-python/commit/c1ac8c1cd30afbc6d70f5471cf1babd49b0c12c6))
* **docs:** grammar improvements ([8733a3f](https://github.com/semilattice-research/semilattice-sdk-python/commit/8733a3f4c68b2f4e8990d53a381789bea1f392fa))
* **docs:** remove reference to rye shell ([f0acd2b](https://github.com/semilattice-research/semilattice-sdk-python/commit/f0acd2bfb7ce9b504c2979c2f39fcaafe5ac316f))
* go live ([#1](https://github.com/semilattice-research/semilattice-sdk-python/issues/1)) ([3bd0d01](https://github.com/semilattice-research/semilattice-sdk-python/commit/3bd0d0143568a7f121ec2116971bb14005fac541))
* **internal:** avoid errors for isinstance checks on proxies ([7b33f65](https://github.com/semilattice-research/semilattice-sdk-python/commit/7b33f6598978418400b58113891571f2a082b3e4))
* **internal:** base client updates ([e07dba5](https://github.com/semilattice-research/semilattice-sdk-python/commit/e07dba5ba6bf7a3116f3b0d1d684926bfe33f7d1))
* **internal:** bump pyright version ([cdfb893](https://github.com/semilattice-research/semilattice-sdk-python/commit/cdfb893656d2e4d749538c64e88d93b6fc8b5e18))
* **internal:** codegen related update ([7772d31](https://github.com/semilattice-research/semilattice-sdk-python/commit/7772d31ef9565b3d897d2b3e33bfafeadc6a0af4))
* **internal:** codegen related update ([587d5d0](https://github.com/semilattice-research/semilattice-sdk-python/commit/587d5d00025329884b13ec67030adcf39b925959))
* **internal:** expand CI branch coverage ([a39b967](https://github.com/semilattice-research/semilattice-sdk-python/commit/a39b9671db6480c8a6e2035663a486b5da4f98af))
* **internal:** fix list file params ([33a6c27](https://github.com/semilattice-research/semilattice-sdk-python/commit/33a6c27bb6299134e0d1b4adad645bde16b3d83e))
* **internal:** import reformatting ([b4c9a2c](https://github.com/semilattice-research/semilattice-sdk-python/commit/b4c9a2cf6adb923fd2e42b40b5c9d658b77b6ebc))
* **internal:** reduce CI branch coverage ([3bf9c86](https://github.com/semilattice-research/semilattice-sdk-python/commit/3bf9c86e70c7ab3e89313a308772eb1640db8486))
* **internal:** refactor retries to not use recursion ([7207fbe](https://github.com/semilattice-research/semilattice-sdk-python/commit/7207fbea409dcecb07d4589e31d1fee798330e7c))
* **internal:** remove trailing character ([#4](https://github.com/semilattice-research/semilattice-sdk-python/issues/4)) ([d67a567](https://github.com/semilattice-research/semilattice-sdk-python/commit/d67a567fe77fea27b04f5efa9794b69a67f46156))
* **internal:** slight transform perf improvement ([#7](https://github.com/semilattice-research/semilattice-sdk-python/issues/7)) ([93fbfde](https://github.com/semilattice-research/semilattice-sdk-python/commit/93fbfdefeacd57633d19157f5d2c48ee3bbc379f))
* **internal:** update models test ([2bb77e9](https://github.com/semilattice-research/semilattice-sdk-python/commit/2bb77e9cf1c63b0653686a29445c4facd187acb2))
* **internal:** update pyright settings ([0435701](https://github.com/semilattice-research/semilattice-sdk-python/commit/043570179672747b7c741e4f3957d11e1d348c13))
* slight wording improvement in README ([#9](https://github.com/semilattice-research/semilattice-sdk-python/issues/9)) ([fb6dc20](https://github.com/semilattice-research/semilattice-sdk-python/commit/fb6dc208e970eda1bb1ccbbca534a4bac8cdf717))
* sync repo ([b163e5c](https://github.com/semilattice-research/semilattice-sdk-python/commit/b163e5c0f939575aedfd471df378722626dc086e))
* sync repo ([97d4227](https://github.com/semilattice-research/semilattice-sdk-python/commit/97d42274857950a7f55fa61a423345a989d0d466))
* update SDK settings ([623e053](https://github.com/semilattice-research/semilattice-sdk-python/commit/623e053c8b47ee6c661e85ce347359faded3d826))
* update SDK settings ([1a14759](https://github.com/semilattice-research/semilattice-sdk-python/commit/1a1475958197a5c541caef84e040043d79b861f9))
* update SDK settings ([b1b747c](https://github.com/semilattice-research/semilattice-sdk-python/commit/b1b747c3e80189c08c5b555efccc1b06d2303fe7))
